from typing import List
from sys import stdin
import subprocess


def execute(command: List[str]):
    """
    Runs the given command in a subprocess and passes stdin (if given) to that process.
    Waits for command to complete.

    :param command: A command to executed as list of words, e.g. ['echo', 'Hello world!']
    :return: (exit_code, stdout, stderr)
    """

    completed: subprocess.CompletedProcess = subprocess.run(
        command,
        stdin=stdin,
        capture_output=True,
        check=False,
        text=True
    )
    return completed.returncode, completed.stdout, completed.stderr
